@@ -1165,7 +1165,7 @@ void PrintVersion(FILE* gStream)
         VERSION_STRING, __DATE__, __TIME__);
     fprintf(gStream, "    Original Copyright (C) 2005 John Hansen.  All Rights Reserved.\n");
     fprintf(gStream, "    Updates  Copyright (C) 2025 Matthew Sheets & contributors.\n");
-    fprintf(gStream, "    Original: https://bricxcc.sf.net/nqc/  Updates: https://BrickBot.GitHub.io/\n");
+    fprintf(gStream, "    https://BrickBot.GitHub.io/nqc ;  Code @ https://GitHub.com/BrickBot/nqc\n");
 }
 
 void PrintUsage()
